--- a/phoneplugins/csplugin/inc/cspcall.h Fri Jun 04 10:19:18 2010 +0100
+++ b/phoneplugins/csplugin/inc/cspcall.h Wed Jun 23 18:12:20 2010 +0300
@@ -499,11 +499,13 @@
/**
* From MCSPCallObserver
* Notify that remote party info has changed.
* @param aRemoteParty new remote party information
*/
- virtual void NotifyRemotePartyInfoChanged(
- const TDesC& aRemoteParty);
+ virtual void NotifyRemotePartyInfoChanged(
+ const TDesC& aRemotePartyName,
+ const TDesC& aRemotePartyNumber );
/**
* Open call handle.
@@ -588,8 +590,14 @@
* @return system wide error code
*/
int UpdateCallState();
+
+ /**
+ * Sends a remote party info changed notification
+ * if the remote party number has changed.
+ */
+ void NotifyRemotePartyNumberChanged();
- private:
+ private:
enum TCSPCallAudioStatus {
ECSPCallAudioStatusInactive,
@@ -499,11 +499,13 @@
/**
* From MCSPCallObserver
- * Notify that remote party info has changed.
- * @param aRemoteParty new remote party information
+ * Notify that remote party info has changed.
+ * @param aRemotePartyName new remote party name
+ * @param aRemotePartyNumber new remote party number
*/